# experimental Makefile for a Pararazzi-Airborne-Code as a Linux usermode-program

#
# This file contains TARGET=linux specific makefile-variables.
# It gets included before the target-specific 
# build-rules in /conf/autopilot/$(TARGET).makefile
# and can be overridden and augmented model-specific via
# the <makefile>-section in conf/airframe/${MODEL}.xml
# This file gets included explicitely in the xml-file.
#
# The variabled are in the format
# ${TARGET}.${NAME}
# where ${NAME} can be
#  ARCHDIR (subdirectory of sw/airborne/ with target-specific code)
#  ARCH    (see gcc -march)
#  TARGET
#  TARGETDIR
#  CFLAGS  (flags to the c-compiler)
#  srcs    (source-files to compile)
#
#  usually srcs and CFLAGS get appended model-specific 
#  files and flags later
#


ARCHI=linux

linux.ARCHDIR = $(ARCHI)
linux.ARCH = i386
linux.TARGET = autopilot
linux.TARGETDIR = autopilot


############
#
# Hardware:
#   uart0 is fixed to a tcp-connection to gpsd
#   uart1 is fixed to a tcp/ip (udp)-connection to the base-station
#   adc   TODO: used for infrared
#   servos TODO
#   I2C    unused
#


############
# main-program
# ap        = compile autopilot
# inter_mcu = communication between the processes "fligh-by-wire" and "autopilot"
# fw_h_ctl.c = fixed-wind horizontal control-loop
# fw_v_ctl.c = fixed-wind vertical   control-loop
# nav.c      = navigation-functions
#   snav     = smooth navigation
#   nav_line/nav_survey_rectangle = specific maneuvers
# sys_time    = contains only 1 global variable and loads sys_time.h and thus our linux/sys_time_hw.h
linux.CFLAGS = -DAP -DINTER_MCU -DSINGLE_MCU
linux.srcs = main.c main_ap.c inter_mcu.c sys_time.c $(SRC_ARCH)/uart_udp.c $(SRC_ARCH)/uart_gpsd.c $(SRC_ARCH)/uart_hw.c  $(SRC_ARCH)/adc_hw.c
linux.srcs += nav.c nav_line.c nav_survey_rectangle.c snav.c

############
# fw_h_ctl.c = fixed-wind horizontal control-loop
# fw_v_ctl.c = fixed-wind vertical   control-loop
# (add this to the <makefike>-section in your
# conf/airframes/$(yourairframe).xml)
#
#linux.srcs += fw_h_ctl.c fw_v_ctl.c

#############
# timer
#linux.CFLAGS += -DPERIODIC_TASK_PERIOD='SYS_TICS_OF_SEC(10e-2)'
#linux.srcs += sys_time.c $(SRC_ARCH)/sys_time_hw.c

##############
# UDP-based downlink 
# (add this to the <makefike>-section in your
# conf/airframes/$(yourairframe).xml)
#
#linux.srcs += downlink.c pprz_transport.c $(SRC_ARCH)/uart_udp.c
#linux.CFLAGS += -DAP -DDOWNLINK -DDOWNLINK_TRANSPORT=PprzTransport -DDOWNLINK_AP_DEVICE=

##############
# we use a ubx-gps
# (add this to the <makefike>-section in your
# conf/airframes/$(yourairframe).xml)
#
# linux.CFLAGS += -DGPS -DUBX -DUSE_UART1 -DGPS_LINK=GPSDUart -DUART1_BAUD=B38400
# linux.srcs += gps_ubx.c gps.c latlong.c

##############
# TODO: we use another gps
# (add this to the <makefike>-section in your
# conf/airframes/$(yourairframe).xml)
#
#linux.CFLAGS += -DGPS -DUSE_UART1 -DGPS_LINK=Uart1 -DUART1_BAUD=B38400
#linux.srcs +=  gps.c latlong.c

##############
# we have an ir-sensor
# estimator.c = brief State estimate, fusioning sensors
# (add this to the <makefike>-section in your
# conf/airframes/$(yourairframe).xml)
#
#
# ap.CFLAGS += -DINFRARED
# ap.srcs += infrared.c estimator.c

LPC21ISP_BAUD = 38400
LPC21ISP_XTAL = 12000

