//include "uart_gpsd.h"
#include <netdb.h>
#include <netinet/in.h>
#include <unistd.h>
#include <string.h>

#ifdef USE_UART0

/**
 * The port gpsd listens on.
 * Default is 2947.
 */
unsigned short int gpsd_serverPort = 2947;

/**
 * The socket to our gpsd-instance.
 * -1 if not connected.
 */
int gpsd_socket;

#define GPSD_BUFFER_SIZE 255
/**
 * Buffer to receive nmea-messages.
 */
uint8_t gpsd_buffer[GPSD_BUFFER_SIZE];
int  gpsd_buffer_received = 0; // how many bytes are in the buffer
int  gpsd_buffer_start = 0;    // index, where to read the next byte

/**
 * simulated uart that connects to GPSD
 * via TCP/IP.
 *
 */

#include "uart.h"
#include "sys_time.h"
#include <stdio.h>

void GPSDuart_init_rx( void ) {
  char *set_raw_mode = "r+\n"; // gpsd-command to enter raw-mode
  int   set_raw_mode_len = strlen(set_raw_mode);
  struct sockaddr_in gpsd_serverAddress;
  //struct hostent    *gpsd_hostInfo;

  printf("GPSDuart_init_rx() - connecting to gpsd on port %i\n", gpsd_serverPort);
  if (gpsd_socket >= 0) 
     close(gpsd_socket);
  gpsd_socket = -1;

  if ((gpsd_socket = socket(PF_INET, SOCK_STREAM, IPPROTO_TCP)) < 0) {
     printf("cannot create TCP-socket to receive from gps-daemon.\n");
     return;
  }

  memset(&gpsd_serverAddress, 0, sizeof(gpsd_serverAddress));     /* Zero out structure */
  gpsd_serverAddress.sin_family      = AF_INET;             /* Internet address family */
  gpsd_serverAddress.sin_addr.s_addr = inet_addr("127.0.0.1");   /* Server IP address */
  gpsd_serverAddress.sin_port        = htons(gpsd_serverPort);

  if (connect(gpsd_socket, (struct sockaddr *) &gpsd_serverAddress, sizeof(gpsd_serverAddress)) < 0) {
     printf("cannot connect TCP-socket to receive from gps-daemon.\n");
     return;
  }

  if (send(gpsd_socket, set_raw_mode, set_raw_mode_len, 0) != set_raw_mode_len) {
     printf("cannot set gps-daemon to raw-mode.\n");
     return;
  }

  printf("GPSDuart_init_rx() - connection to gpsd established\n");
}

void GPSDuart_init_tx( void ) {
  printf("uart1_init_tx() - ignored\n");
}

void GPSDuart_transmit( unsigned char data ) {
  printf("uart1_transmit() - ignored\n");
}

int GPSDUartChAvailable() {
  printf("GPSDUartChAvailable()\n");

  // does the buffer contain unreat bytes?
  if (gpsd_buffer_received > 0 && gpsd_buffer_start <= gpsd_buffer_received)
     return TRUE;

  // read from the socket
  if ((gpsd_buffer_received = recv(gpsd_socket, gpsd_buffer, GPSD_BUFFER_SIZE - 1, 0)) <= 0) {
    printf("GPSDUartChAvailable() - receive from gpsd failed. re-opening connection\n");
    GPSDuart_init_rx();
    return FALSE;
  }
  gpsd_buffer_start = 0;
  return (gpsd_buffer_received > 0);
}

uint8_t GPSDUartGetch() {
  printf("GPSDUartGetch()\n");
  uint8_t retval = gpsd_buffer[gpsd_buffer_start];
  gpsd_buffer_start ++;
  return retval;
}


#endif
