/*
 * Paparazzi $Id: uart_hw.c,v 1.11 2006/07/12 07:24:36 poine Exp $
 *  
 * Copyright (C) 2003 Pascal Brisset, Antoine Drouin
 *
 * This file is part of paparazzi.
 *
 * paparazzi is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * paparazzi is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with paparazzi; see the file COPYING.  If not, write to
 * the Free Software Foundation, 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA. 
 *
 */

/** 
 * file uart_hw.c
 * Low-Level uart-emulation
 *
 */
#include "uart.h"
#include "uart_hw.h"
#include "uart_udp.h"
#include "uart_gpsd.h"
#include "sys_time.h"
#include <stdio.h>

// uart0 = udp-connection to ground-station

#ifdef USE_UART0


/*
 * UART Baud rate generation settings:
 *
 * With 16.0 MHz clock,UBRR=25  => 38400 baud
 *
 */

void uart0_init_tx( void ) {
  UDPuart_init_tx();
}

void uart0_init_rx( void ) {
  UDPuart_init_rx();
}


void uart0_transmit( unsigned char data ) {
   UDPuart_transmit(data);
}

int Uart0ChAvailable() {
   return UDPuartChAvailable();
}

uint8_t Uart0Getch() {
  return UDPuartGetch();
}

#endif /** USE_UART0 */


// uart1 = TCP-connection to a GPSD

#ifdef USE_UART1


void uart1_init_tx( void ) {
   GPSDuart_init_tx();
}

void uart1_init_rx( void ) {
   GPSDuart_init_rx();
}

/**
 * Alias for GPSDuart_transmit.
 * Required for ublox-code.
 */
void uart1_transmit( unsigned char data ) {
  GPSDuart_transmit(data);
}

int Uart1ChAvailable() {
   return GPSDUartChAvailable();
}

uint8_t Uart1Getch() {
  return GPSDUartGetch();
}



#endif /** USE_UART1 */



